@@ -135,6 +135,14 @@ QColor CCanvas::getSelectedColor()
     return mouseColorPicker->getSelectedColor();
 }
 
+void CCanvas::slotMapChanged()
+{
+    if(mouse)
+    {
+        mouse->slotMapChanged();
+    }
+    update();
+}
 
 void CCanvas::slotCopyPosition()
 {
@@ -426,29 +434,57 @@ void CCanvas::print(QImage& img, const QSize& pagesize)
 }
 
 
+#undef DEBUG_DRAW
+#ifdef DEBUG_DRAW
+
+#define DEBUG_TIME(label)\
+    qDebug() << label << et.restart() << "ms";
+#else
+    #define DEBUG_TIME(label)
+#endif
+
 void CCanvas::draw(QPainter& p)
 {
     IMap& map = CMapDB::self().getMap();
     bool needsRedraw = map.getNeedsRedraw();
 
     USE_ANTI_ALIASING(p,!map.getFastDrawFlag() && CResources::self().useAntiAliasing());
+#ifdef DEBUG_DRAW
+    QElapsedTimer et;
+    et.restart();
+#endif
 
     CMapDB::self().draw(p,rect(), needsRedraw);
+    DEBUG_TIME("CMapDB:     ");
     CRouteDB::self().draw(p, rect(), needsRedraw);
+    DEBUG_TIME("CRouteDB:   ");
     CTrackDB::self().draw(p, rect(), needsRedraw);
+    DEBUG_TIME("CTrackDB:   ");
     COverlayDB::self().draw(p, rect(), needsRedraw);
+    DEBUG_TIME("COverlayDB: ");
     CLiveLogDB::self().draw(p, rect(), needsRedraw);
+    DEBUG_TIME("CLiveLogDB: ");
     CWptDB::self().draw(p, rect(), needsRedraw);
+    DEBUG_TIME("CWptDB:     ");
     CSearchDB::self().draw(p, rect(), needsRedraw);
+    DEBUG_TIME("CSearchDB:  ");
     CGridDB::self().draw(p, rect(), needsRedraw);
+    DEBUG_TIME("CGridDB:    ");
 
     drawRefPoints(p);
     drawScale(p);
     drawCompass(p);
     drawClock(p);
     drawFadingMessage(p);
+    drawTrackLegend(p);
+    DEBUG_TIME("Other:      ");
 
     mouse->draw(p);
+    DEBUG_TIME("Mouse:      ");
+
+#ifdef DEBUG_DRAW
+    qDebug() << "-----------------------";
+#endif
 }
 
 
@@ -968,6 +1004,7 @@ void CCanvas::slotHighlightTrack(CTrack * track)
         profile->hide();
         disconnect(profile, SIGNAL(sigClicked()), CTrackDB::self().getToolWidget(), SLOT(slotShowProfile()));
     }
+    update();
 }
 
 
@@ -1022,3 +1059,20 @@ void CCanvas::drawFadingMessage(QPainter& p)
     p.setPen(Qt::darkBlue);
     p.drawText(r1, Qt::AlignLeft|Qt::AlignTop|Qt::TextWordWrap,fadingMessage);
 }
+
+void CCanvas::drawTrackLegend(QPainter& p)
+{
+    CTrack * track = CTrackDB::self().highlightedTrack();
+    if(track == 0)
+    {
+        return;
+    }
+
+    QPoint pt = profile->pos();
+
+    p.save();
+    p.translate(pt.x(), pt.y() - 30 - 200);
+    track->drawMultiColorLegend(p);
+    p.restore();
+
+}
