@@ -5,12 +5,12 @@
     it under the terms of the GNU General Public License as published by
     the Free Software Foundation, either version 3 of the License, or
     (at your option) any later version.
-    
+
     This program is distributed in the hope that it will be useful,
     but WITHOUT ANY WARRANTY; without even the implied warranty of
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.
-    
+
     You should have received a copy of the GNU General Public License
     along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
@@ -138,6 +138,9 @@ class CCanvas : public QWidget
         signals:
         void sigResize(const QSize& size);
 
+    public slots:
+        void slotMapChanged();
+
     private slots:
         void slotCopyPosition();
         void slotHighlightTrack(CTrack * track);
@@ -169,6 +172,7 @@ class CCanvas : public QWidget
         void drawCompass(QPainter& p);
         void drawClock(QPainter& p);
         void drawFadingMessage(QPainter& p);
+        void drawTrackLegend(QPainter& p);
 
     private:
         friend class CStatusCanvas;
