@@ -1,9 +1,9 @@
 /**********************************************************************************************
     Copyright (C) 2008 Oliver Eichler oliver.eichler@gmx.de
 
-    This program is free software; you can redistribute it and/or modify
+    This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
+    the Free Software Foundation, either version 3 of the License, or
     (at your option) any later version.
 
     This program is distributed in the hope that it will be useful,
@@ -12,8 +12,7 @@
     GNU General Public License for more details.
 
     You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 **********************************************************************************************/
 
@@ -241,7 +240,7 @@ void CCreateMapGeoTiff::slotOpenFile()
     SETTINGS;
     path = QDir(cfg.value("path/create",path.path()).toString());
 
-    QString filename = QFileDialog::getOpenFileName(0, tr("Open map file..."),path.path(), tr("Raw bitmaps (*.tif *.tiff *.png *.gif)"), 0, FILE_DIALOG_FLAGS);
+    QString filename = QFileDialog::getOpenFileName(0, tr("Open map file..."),path.path(), tr("Raw bitmaps (*.tif *.tiff *.png *.gif *.jpg)"), 0, FILE_DIALOG_FLAGS);
     if(filename.isEmpty()) return;
 
     CMapDB::self().openMap(filename, true, *theMainWindow->getCanvas());
@@ -690,10 +689,10 @@ void CCreateMapGeoTiff::saveTAB(const QString& filename)
 
 
 void CCreateMapGeoTiff::slotGridTool()
-{    
+{
     rectSelArea = QRect(QPoint(0,0),sizeMap);
     CCreateMapGridTool * tool = new CCreateMapGridTool(this, parentWidget());
-    theMainWindow->setTempWidget(tool, tr("Grid Tool"));    
+    theMainWindow->setTempWidget(tool, tr("Grid Tool"));
 }
 
 
