@@ -1,9 +1,9 @@
 /**********************************************************************************************
     Copyright (C) 2012 Oliver Eichler oliver.eichler@gmx.de
 
-    This program is free software; you can redistribute it and/or modify
+    This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
+    the Free Software Foundation, either version 3 of the License, or
     (at your option) any later version.
 
     This program is distributed in the hope that it will be useful,
@@ -12,8 +12,7 @@
     GNU General Public License for more details.
 
     You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 **********************************************************************************************/
 
@@ -93,6 +92,8 @@ void CDeviceGarminBulk::readDeviceXml(const QString& filename)
 
 bool CDeviceGarminBulk::aquire(QDir& dir)
 {
+    QMessageBox::StandardButton res;
+
     SETTINGS;
     QString path = cfg.value("device/path","").toString();
     dir.setPath(path);
@@ -140,20 +141,42 @@ bool CDeviceGarminBulk::aquire(QDir& dir)
 
             if(!dir.exists(pathGpx))
             {
-                QMessageBox::critical(0, tr("Missing..."), tr("The selected path must have a subdirectory '%1'.").arg(pathGpx), QMessageBox::Abort, QMessageBox::Abort);
-                continue;
+                res = QMessageBox::critical(0, tr("Missing..."), tr("The selected path must have a subdirectory '%1'. Should I create the path?\n\n%2").arg(pathGpx).arg(dir.absoluteFilePath(pathGpx)), QMessageBox::Abort|QMessageBox::Yes, QMessageBox::Abort);
+                if(res == QMessageBox::Yes)
+                {
+                    dir.mkpath(pathGpx);
+                }
+                else
+                {
+                    continue;
+                }
             }
 
             if(!pathPictures.isEmpty() && !dir.exists(pathPictures))
             {
-                QMessageBox::critical(0, tr("Missing..."), tr("The selected path must have a subdirectory '%1'.").arg(pathPictures), QMessageBox::Abort, QMessageBox::Abort);
-                continue;
+                res = QMessageBox::critical(0, tr("Missing..."), tr("The selected path must have a subdirectory '%1'. Should I create the path?\n\n%2").arg(pathPictures).arg(dir.absoluteFilePath(pathPictures)), QMessageBox::Abort|QMessageBox::Yes, QMessageBox::Abort);
+                if(res == QMessageBox::Yes)
+                {
+                    dir.mkpath(pathPictures);
+                }
+                else
+                {
+                    continue;
+                }
             }
 
             if(!pathSpoilers.isEmpty() && !dir.exists(pathSpoilers))
             {
-                QMessageBox::critical(0, tr("Missing..."), tr("The selected path must have a subdirectory '%1'.").arg(pathSpoilers), QMessageBox::Abort, QMessageBox::Abort);
-                continue;
+
+                res = QMessageBox::critical(0, tr("Missing..."), tr("The selected path must have a subdirectory '%1. Should I create the path?\n\n%2").arg(pathSpoilers).arg(dir.absoluteFilePath(pathSpoilers)), QMessageBox::Abort|QMessageBox::Yes, QMessageBox::Abort);
+                if(res == QMessageBox::Yes)
+                {
+                    dir.mkpath(pathSpoilers);
+                }
+                else
+                {
+                    continue;
+                }
             }
 
             break;
