@@ -42,6 +42,7 @@ CDlgEditWpt::CDlgEditWpt(CWpt &wpt, QWidget * parent)
 #ifdef HAS_DMTX
 , enc(0)
 #endif
+, silentSpoilerQuery(false)
 {
     setupUi(this);
     connect(pushAdd, SIGNAL(clicked()), this, SLOT(slotAddImage()));
@@ -110,7 +111,7 @@ CDlgEditWpt::CDlgEditWpt(CWpt &wpt, QWidget * parent)
 
 CDlgEditWpt::~CDlgEditWpt()
 {
-    //wpt.showBuddies(false);
+    wpt.showBuddies(false);
 #ifdef HAS_DMTX
     dmtxEncodeDestroy(&enc);
 #endif
@@ -266,6 +267,12 @@ int CDlgEditWpt::exec()
 
     lineName->setFocus();
 
+    if(wpt.isGeoCache() && !wpt.link.isEmpty() && wpt.images.isEmpty())
+    {
+        silentSpoilerQuery = true;
+        triggerSpoilerDownload();
+    }
+
     return QDialog::exec();
 }
 
@@ -644,13 +651,21 @@ void CDlgEditWpt::slotCollectSpoiler()
                 pushDel->setEnabled(false);
             }
         }
-
-        QNetworkRequest request;
-        request.setUrl(wpt.link);
-        networkAccessManager->get(request);
+        triggerSpoilerDownload();
     }
 }
 
+void CDlgEditWpt::triggerSpoilerDownload()
+{
+    QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
+
+    pendingRequests.clear();
+
+    QNetworkRequest request;
+    request.setUrl(wpt.link);
+    networkAccessManager->get(request);
+}
+
 void CDlgEditWpt::slotProxyAuthenticationRequired(const QNetworkProxy &prox, QAuthenticator *auth)
 {
     QString user;
@@ -672,11 +687,17 @@ void CDlgEditWpt::slotRequestFinished(QNetworkReply * reply)
     if(pendingRequests.contains(reply))
     {
         CWpt::image_t img;
-        img.info = pendingRequests[reply];
+        img.info = pendingRequests.take(reply);
         img.pixmap.loadFromData(reply->readAll());
         wpt.images.push_back(img);
         showImage(wpt.images.count() - 1);
         pushDel->setEnabled(true);
+
+        if(pendingRequests.isEmpty())
+        {
+            QApplication::restoreOverrideCursor();
+        }
+
         return;
     }
 
@@ -689,16 +710,31 @@ void CDlgEditWpt::slotRequestFinished(QNetworkReply * reply)
     }
 
 
-    QRegExp re1(".*alt=\"Photos\" title=\"Photos\".*");
-    QRegExp re2("(http://img.geocaching.com/cache/large/.*\\.jpg).*<span>(.*)</span>");
+    QRegExp re0(".*Object moved to <a href=\"(.*)\".*");
+    QRegExp re1(".*CachePageImages.*");
+    QRegExp re2("(http://img.geocaching.com/cache/large/.*\\.jpg).*>(.*)</a>");
+
     re2.setMinimal(true);
 
-
-    bool spoilerFound = false;
-    QStringList lines = asw.split("\n");
+    bool watchOut       = false;
+    bool spoilerFound   = false;
+    QStringList lines   = asw.split("\n");
     foreach(const QString& line, lines)
     {
-        if(re1.exactMatch(line))
+        if(re0.exactMatch(line))
+        {
+            QString url  = re0.cap(1);
+
+            QNetworkRequest request;
+            request.setUrl(url);
+            networkAccessManager->get(request);
+            return;
+        }
+        else if(!watchOut && re1.exactMatch(line))
+        {
+            watchOut = true;
+        }
+        else if(watchOut)
         {
             int pos = 0;
             while ((pos = re2.indexIn(line, pos)) != -1)
@@ -714,12 +750,17 @@ void CDlgEditWpt::slotRequestFinished(QNetworkReply * reply)
 
                 pos += re2.matchedLength();
             }
+
+            watchOut = false;
         }
     }
 
-    if(!spoilerFound)
+    if(!spoilerFound && !silentSpoilerQuery)
     {
+        QApplication::restoreOverrideCursor();
         QMessageBox::information(0,tr("No spoilers..."), tr("No spoilers found."), QMessageBox::Ok);
     }
 
+    silentSpoilerQuery = false;
+
 }
