@@ -1,19 +1,18 @@
 /**********************************************************************************************
     Copyright (C) 2009 Joerg Wunsch <j@uriah.heep.sax.de>
 
-    This program is free software; you can redistribute it and/or modify
+    This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
+    the Free Software Foundation, either version 3 of the License, or
     (at your option) any later version.
-
+    
     This program is distributed in the hope that it will be useful,
     but WITHOUT ANY WARRANTY; without even the implied warranty of
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.
-
+    
     You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 **********************************************************************************************/
 
@@ -261,8 +260,6 @@ void CDlgTrackFilter::modifyTimestamp(CTrack * trk)
 
         track.setTimestamp(trkpts.begin()->timestamp);
         track.rebuild(false);
-
-        CTrackDB::self().emitSigModified();
     }
 }
 
@@ -406,8 +403,6 @@ void CDlgTrackFilter::reduceDataset(CTrack * trk)
         }
         progress.setValue(npts);
         track.rebuild(false);
-
-        CTrackDB::self().emitSigModified();
     }
 }
 
