@@ -1,19 +1,18 @@
 /**********************************************************************************************
     Copyright (C) 2008 Oliver Eichler oliver.eichler@gmx.de
 
-    This program is free software; you can redistribute it and/or modify
+    This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
+    the Free Software Foundation, either version 3 of the License, or
     (at your option) any later version.
-
+    
     This program is distributed in the hope that it will be useful,
     but WITHOUT ANY WARRANTY; without even the implied warranty of
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.
-
+    
     You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 **********************************************************************************************/
 
@@ -29,6 +28,7 @@
 #include "CTrackDB.h"
 #include "CTrack.h"
 #include "IUnit.h"
+#include "CSettings.h"
 
 #include <QtGui>
 
@@ -42,8 +42,13 @@ CLiveLogDB * CLiveLogDB::m_self = 0;
 CLiveLogDB::CLiveLogDB(QTabWidget * tb, QObject * parent)
 : IDB(IDB::eTypeLog,  tb, parent)
 , m_lockToCenter(false)
+, m_useSmallArrow(false)
 {
     m_self      = this;
+
+    SETTINGS;
+    m_useSmallArrow = cfg.value("livelog/useSmallArrow", m_useSmallArrow).toBool();
+
     toolview    = new CLiveLogToolWidget(tb);
 
     connect(&CMapDB::self(), SIGNAL(sigChanged()), this, SLOT(slotMapDBChanged()));
@@ -51,12 +56,14 @@ CLiveLogDB::CLiveLogDB(QTabWidget * tb, QObject * parent)
 
     saveBackupLog();
     backup = new QFile(QDir::temp().filePath("qlBackupLog"),this);
+
 }
 
 
 CLiveLogDB::~CLiveLogDB()
 {
-
+    SETTINGS;
+    cfg.setValue("livelog/useSmallArrow", m_useSmallArrow);
 }
 
 
@@ -370,11 +377,12 @@ void CLiveLogDB::draw(QPainter& p, const QRect& rect, bool& needsRedraw)
     p.setPen(QPen(Qt::black,3));
     p.drawPolyline(polyline);
 
-    IMap& map = CMapDB::self().getMap();
     if( (m_log.fix == CLiveLog::e2DFix) ||
         (m_log.fix == CLiveLog::e3DFix) ||
         (m_log.fix == CLiveLog::eEstimated) )
     {
+        IMap& map = CMapDB::self().getMap();
+
         double u = m_log.lon * DEG_TO_RAD;
         double v = m_log.lat * DEG_TO_RAD;
         map.convertRad2Pt(u,v);
@@ -385,7 +393,31 @@ void CLiveLogDB::draw(QPainter& p, const QRect& rect, bool& needsRedraw)
             p.save();
             p.translate(u,v);
             p.rotate(heading);
-            p.drawPixmap(-23,-30,QPixmap(":/cursors/cursor1.png"));
+            if(m_useSmallArrow)
+            {
+                QPolygon arrow;
+                arrow << QPoint(0,-50);
+                arrow << QPoint(5,-40);
+                arrow << QPoint(-5,-40);
+                arrow << QPoint(0,-50);
+
+                p.setPen(QPen(Qt::white,5));
+                p.setBrush(Qt::white);
+                p.drawEllipse(-4,-4,8,8);
+                p.drawLine(0,0,0,-50);
+                p.drawPolygon(arrow);
+
+                p.setPen(QPen(Qt::black,3));
+                p.setBrush(Qt::black);
+                p.drawEllipse(-4,-4,8,8);
+                p.drawLine(0,0,0,-50);
+                p.drawPolygon(arrow);
+
+            }
+            else
+            {
+                p.drawPixmap(-23,-30,QPixmap(":/cursors/cursor1.png"));
+            }
             p.restore();
         }
         else
