@@ -1,19 +1,18 @@
 /**********************************************************************************************
     Copyright (C) 2008-2009 Oliver Eichler oliver.eichler@gmx.de
 
-    This program is free software; you can redistribute it and/or modify
+    This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
+    the Free Software Foundation, either version 3 of the License, or
     (at your option) any later version.
-
+    
     This program is distributed in the hope that it will be useful,
     but WITHOUT ANY WARRANTY; without even the implied warranty of
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.
-
+    
     You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 **********************************************************************************************/
 
@@ -296,12 +295,12 @@ CMainWindow::CMainWindow()
     connect(routedb, SIGNAL(sigChanged()), this, SLOT(update()));
     connect(mapdb, SIGNAL(sigChanged()), this, SLOT(update()));
 
-    connect(mapdb, SIGNAL(sigModified()), this, SLOT(slotModified()));
-    connect(wptdb, SIGNAL(sigModified()), this, SLOT(slotModified()));
-    connect(trackdb, SIGNAL(sigModified()), this, SLOT(slotModified()));
-    connect(diarydb, SIGNAL(sigModified()), this, SLOT(slotModified()));
-    connect(overlaydb, SIGNAL(sigModified()), this, SLOT(slotModified()));
-    connect(routedb, SIGNAL(sigModified()), this, SLOT(slotModified()));
+    connect(mapdb, SIGNAL(sigModified(const QString&)), this, SLOT(slotModified()));
+    connect(wptdb, SIGNAL(sigModified(const QString&)), this, SLOT(slotModified()));
+    connect(trackdb, SIGNAL(sigModified(const QString&)), this, SLOT(slotModified()));
+    connect(diarydb, SIGNAL(sigModified(const QString&)), this, SLOT(slotModified()));
+    connect(overlaydb, SIGNAL(sigModified(const QString&)), this, SLOT(slotModified()));
+    connect(routedb, SIGNAL(sigModified(const QString&)), this, SLOT(slotModified()));
 
     if(geodb)
     {
