@@ -5,12 +5,12 @@
     it under the terms of the GNU General Public License as published by
     the Free Software Foundation, either version 3 of the License, or
     (at your option) any later version.
-    
+
     This program is distributed in the hope that it will be useful,
     but WITHOUT ANY WARRANTY; without even the implied warranty of
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.
-    
+
     You should have received a copy of the GNU General Public License
     along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
@@ -450,7 +450,7 @@ void CMapDB::openMap(const QString& filename, bool asRaster, CCanvas& canvas)
         }
     }
 
-    connect(theMap, SIGNAL(sigChanged()),  theMainWindow->getCanvas(), SLOT(update()));
+    connect(theMap, SIGNAL(sigChanged()),  theMainWindow->getCanvas(), SLOT(slotMapChanged()));
 
     QString fileDEM = cfg.value(QString("map/dem/%1").arg(theMap->getKey()),"").toString();
     openDEM(fileDEM);
@@ -517,7 +517,7 @@ void CMapDB::openMap(const QString& key)
         theMap = new CMapTms(key, theMainWindow->getCanvas());
     }
 
-    connect(theMap, SIGNAL(sigChanged()), theMainWindow->getCanvas(), SLOT(update()));
+    connect(theMap, SIGNAL(sigChanged()), theMainWindow->getCanvas(), SLOT(slotMapChanged()));
 
     // store current map filename for next session
     SETTINGS;
