@@ -1,19 +1,18 @@
 /**********************************************************************************************
     Copyright (C) 2008 Oliver Eichler oliver.eichler@gmx.de
 
-    This program is free software; you can redistribute it and/or modify
+    This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
+    the Free Software Foundation, either version 3 of the License, or
     (at your option) any later version.
-
+    
     This program is distributed in the hope that it will be useful,
     but WITHOUT ANY WARRANTY; without even the implied warranty of
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.
-
+    
     You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 **********************************************************************************************/
 #include <assert.h>
@@ -206,7 +205,10 @@ CMapDEM::~CMapDEM()
 {
     qDebug() << "CMapDEM::~CMapDEM()";
 
-    CMapDEMSlopeSetup::self().registerDEMMap(0);
+    if(CMapDEMSlopeSetup::self())
+    {
+        CMapDEMSlopeSetup::self()->registerDEMMap(0);
+    }
 
     SETTINGS;
     cfg.setValue("map/overlay/grade",idxGrade);
@@ -458,15 +460,15 @@ void CMapDEM::draw()
 
     IMap::overlay_e overlay = status->getOverlayType();
 
-    if(overlay != old_overlay)
+    if(CMapDEMSlopeSetup::self() && (overlay != old_overlay))
     {
         if(overlay == IMap::eSlope)
         {
-            CMapDEMSlopeSetup::self().registerDEMMap(this);
+            CMapDEMSlopeSetup::self()->registerDEMMap(this);
         }
         else
         {
-            CMapDEMSlopeSetup::self().registerDEMMap(0);
+            CMapDEMSlopeSetup::self()->registerDEMMap(0);
         }
     }
 
@@ -592,10 +594,6 @@ void CMapDEM::draw()
     {
         contour(img,data.data(), my_xscale, my_yscale);
     }
-    else if(overlay == IMap::eContour)
-    {
-        slope(img,data.data(), my_xscale, my_yscale);
-    }
     else if(overlay == IMap::eSlope)
     {
         slope(img,data.data(), xoff1, yoff1);
