@@ -1,9 +1,9 @@
 /**********************************************************************************************
     Copyright (C) 2008 Oliver Eichler oliver.eichler@gmx.de
 
-    This program is free software; you can redistribute it and/or modify
+    This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
+    the Free Software Foundation, either version 3 of the License, or
     (at your option) any later version.
 
     This program is distributed in the hope that it will be useful,
@@ -12,8 +12,7 @@
     GNU General Public License for more details.
 
     You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 **********************************************************************************************/
 
@@ -61,13 +60,15 @@ void CMouseMoveWpt::mousePressEvent(QMouseEvent * e)
 {
     if(e->button() == Qt::LeftButton)
     {
-        if(!moveWpt && !selWpt.isNull())
+        if(!moveWpt && (selWpts.size() == 1))
         {
             newPos = e->pos();
             moveWpt = true;
         }
-        else if(moveWpt && !selWpt.isNull() && selWpt->isMovable())
+        else if(moveWpt && (selWpts.size() == 1) && selWpts.first().wpt->isMovable())
         {
+            CWpt * selWpt = selWpts.first().wpt;
+
             IMap& map = CMapDB::self().getMap();
             double u = e->pos().x();
             double v = e->pos().y();
@@ -78,9 +79,7 @@ void CMouseMoveWpt::mousePressEvent(QMouseEvent * e)
             float ele = CMapDB::self().getDEM().getElevation(selWpt->lon * DEG_TO_RAD, selWpt->lat * DEG_TO_RAD);
             if(ele != WPT_NOFLOAT) selWpt->ele = ele;
 
-            emit CWptDB::self().sigChanged();
-            emit CWptDB::self().sigModified();
-            emit CWptDB::self().sigModified(selWpt->getKey());
+            CWptDB::self().emitSigModified(selWpt->getKey());
 
             moveWpt = false;
             canvas->setMouseMode(CCanvas::eMouseMoveArea);
@@ -102,8 +101,10 @@ void CMouseMoveWpt::mouseReleaseEvent(QMouseEvent * e)
 
 void CMouseMoveWpt::draw(QPainter& p)
 {
-    if(moveWpt && !selWpt.isNull() && selWpt->isMovable())
+    if(moveWpt && (selWpts.size() == 1) && selWpts.first().wpt->isMovable())
     {
+        CWpt * selWpt = selWpts.first().wpt;
+
         double x1, y1, x2, y2;
         projXY p1, p2;
         IMap& map = CMapDB::self().getMap();
