@@ -1,9 +1,9 @@
 /**********************************************************************************************
     Copyright (C) 2008 Oliver Eichler oliver.eichler@gmx.de
 
-    This program is free software; you can redistribute it and/or modify
+    This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
+    the Free Software Foundation, either version 3 of the License, or
     (at your option) any later version.
 
     This program is distributed in the hope that it will be useful,
@@ -12,8 +12,7 @@
     GNU General Public License for more details.
 
     You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 **********************************************************************************************/
 
@@ -352,7 +351,6 @@ void COverlayDB::delOverlays(const QStringList& keys)
     if(!keys.isEmpty())
     {
         emitSigChanged();
-        emitSigModified();
     }
 
 }
@@ -368,7 +366,6 @@ void COverlayDB::delOverlay(const QString& key, bool silent)
         if(!silent)
         {
             emitSigChanged();
-            emitSigModified();
         }
     }
 }
@@ -392,9 +389,7 @@ COverlayText * COverlayDB::addText(const QString& text, const QRect& rect, const
 
     overlays[overlay->getKey()] = overlay;
 
-    connect(overlay, SIGNAL(sigChanged()),SIGNAL(sigChanged()));
-    connect(overlay, SIGNAL(sigChanged()),SIGNAL(sigModified()));
-    connect(overlay, SIGNAL(sigChanged()),SLOT(slotModified()));
+    connect(overlay, SIGNAL(sigChanged()),this, SLOT(slotModified()));
 
     if(!silent)
     {
@@ -423,9 +418,7 @@ COverlayTextBox * COverlayDB::addTextBox(const QString& text, double lon, double
 
     overlays[overlay->getKey()] = overlay;
 
-    connect(overlay, SIGNAL(sigChanged()),SIGNAL(sigChanged()));
-    connect(overlay, SIGNAL(sigChanged()),SIGNAL(sigModified()));
-    connect(overlay, SIGNAL(sigChanged()),SLOT(slotModified()));
+    connect(overlay, SIGNAL(sigChanged()),this, SLOT(slotModified()));
 
     if(!silent)
     {
@@ -454,9 +447,7 @@ COverlayDistance * COverlayDB::addDistance(const QString& name, const QString& c
 
     overlays[overlay->getKey()] = overlay;
 
-    connect(overlay, SIGNAL(sigChanged()),SIGNAL(sigChanged()));
-    connect(overlay, SIGNAL(sigChanged()),SIGNAL(sigModified()));
-    connect(overlay, SIGNAL(sigChanged()),SLOT(slotModified()));
+    connect(overlay, SIGNAL(sigChanged()),this, SLOT(slotModified()));
 
     if(!silent)
     {
@@ -534,8 +525,6 @@ void COverlayDB::pasteFromClipboard()
         qlb.load(&buffer);
 
         loadQLB(qlb, true);
-
-        emitSigModified();
     }
 }
 
@@ -565,10 +554,8 @@ void COverlayDB::highlightOverlay(const QString& key)
         }
 
         ovl->setHighlight(true);
+        emit sigModified(ovl->getKey());
     }
-
-    emitSigChanged();
-
 }
 
 
