@@ -5,12 +5,12 @@
     it under the terms of the GNU General Public License as published by
     the Free Software Foundation, either version 3 of the License, or
     (at your option) any later version.
-    
+
     This program is distributed in the hope that it will be useful,
     but WITHOUT ANY WARRANTY; without even the implied warranty of
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.
-    
+
     You should have received a copy of the GNU General Public License
     along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
@@ -639,6 +639,7 @@ void CPlot::drawXScale( QPainter &p )
 
 void CPlot::drawYScale( QPainter &p )
 {
+    QString format_single_prec;
     QRect recText;
     if ( m_pData->y().getTicType() == CPlotAxis::notic )
         return ;
@@ -651,18 +652,47 @@ void CPlot::drawYScale( QPainter &p )
     int iy;
 
     ix = left - scaleWidthY1 - deadAreaX;
+
+    double limMin, limMax, useMin, useMax;
+    m_pData->y().getLimits(limMin, limMax, useMin, useMax);
+
+    // draw min/max lables 1st;
+    QRect recTextMin;
+    QRect recTextMax;
+
+    format_single_prec = m_pData->y().fmtsgl(m_pData->ymin);
+    if(m_pData->ymin >= useMin)
+    {
+        iy = bottom - m_pData->y().val2pt( m_pData->ymin ) - fontHeight / 2;
+        recText.moveTopLeft( QPoint( ix, iy ) );
+        p.drawText( recText, Qt::AlignRight, QString().sprintf( format_single_prec.toLatin1().data(), m_pData->ymin  ));
+        recTextMin = recText;
+    }
+    format_single_prec = m_pData->y().fmtsgl(m_pData->ymax);
+    if(m_pData->ymax <= useMax)
+    {
+        iy = bottom - m_pData->y().val2pt( m_pData->ymax ) - fontHeight / 2;
+        recText.moveTopLeft( QPoint( ix, iy ) );
+        p.drawText( recText, Qt::AlignRight, QString().sprintf( format_single_prec.toLatin1().data(), m_pData->ymax  ));
+        recTextMax = recText;
+    }
+
+    // draw tic marks
     const CPlotAxis::TTic * t = m_pData->y().ticmark();
     while ( t )
     {
         iy = bottom - m_pData->y().val2pt( t->val ) - fontHeight / 2;
 
         recText.moveTopLeft( QPoint( ix, iy ) );
-        p.drawText( recText, Qt::AlignRight, t->lbl );
+
+        if(!recTextMin.intersects(recText) && !recTextMax.intersects(recText))
+        {
+            p.drawText( recText, Qt::AlignRight, t->lbl );
+        }
+
         t = m_pData->y().ticmark( t );
     }
 
-    double limMin, limMax, useMin, useMax;
-    m_pData->y().getLimits(limMin, limMax, useMin, useMax);
 
     if((limMax - limMin) <= (useMax - useMin)) return;
 
@@ -761,6 +791,23 @@ void CPlot::drawGridY( QPainter &p )
         p.drawLine( ix, iy, ix + dx, iy );
         t = m_pData->y().ticmark( t );
     }
+
+    // draw min/max lines
+    double limMin, limMax, useMin, useMax;
+    m_pData->y().getLimits(limMin, limMax, useMin, useMax);
+
+    if(m_pData->ymin > useMin)
+    {
+        iy = bottom - m_pData->y().val2pt( m_pData->ymin );
+        p.drawLine( ix, iy, ix + dx, iy );
+    }
+    if(m_pData->ymax < useMax)
+    {
+        iy = bottom - m_pData->y().val2pt( m_pData->ymax );
+        p.drawLine( ix, iy, ix + dx, iy );
+    }
+
+
     p.setPen( oldpen );
     m_pData->y().setTicType( oldtic );
 }
@@ -796,7 +843,7 @@ QColor colors[] =
 void CPlot::drawData(QPainter& p)
 {
     int penIdx = 0;
-    int ptx, pty;
+    int ptx, pty, oldPtx;
     QList<CPlotData::line_t> lines                  = m_pData->lines;
     QList<CPlotData::line_t>::const_iterator line   = lines.begin();
 
@@ -813,6 +860,7 @@ void CPlot::drawData(QPainter& p)
 
         ptx = left   + xaxis.val2pt( point->x() );
         pty = bottom - yaxis.val2pt( point->y() );
+        oldPtx = ptx;
 
         background << QPointF(left,bottom);
         background << QPointF(left,pty);
@@ -823,6 +871,13 @@ void CPlot::drawData(QPainter& p)
             ptx = left   + xaxis.val2pt( point->x() );
             pty = bottom - yaxis.val2pt( point->y() );
 
+            if(oldPtx == ptx)
+            {
+                ++point;
+                continue;
+            }
+            oldPtx = ptx;
+
             if(ptx >= left && ptx <= right)
             {
                 background << QPointF(ptx,pty);
