@@ -1,9 +1,9 @@
 /**********************************************************************************************
     Copyright (C) 2007 Oliver Eichler oliver.eichler@gmx.de
 
-    This program is free software; you can redistribute it and/or modify
+    This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
+    the Free Software Foundation, either version 3 of the License, or
     (at your option) any later version.
 
     This program is distributed in the hope that it will be useful,
@@ -12,8 +12,7 @@
     GNU General Public License for more details.
 
     You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 **********************************************************************************************/
 
@@ -76,6 +75,7 @@ CResources::CResources(QObject * parent)
 , m_showClock(true)
 , m_showScale(true)
 , m_showToolTip(true)
+, m_showElementInfo(true)
 , m_showZoomLevel(true)
 , m_useAntiAliasing(true)
 , m_reducePoiIcons(true)
@@ -163,6 +163,7 @@ CResources::CResources(QObject * parent)
     m_showClock        = cfg.value("environment/showClock",m_showClock).toBool();
     m_showScale        = cfg.value("environment/showScale",m_showScale).toBool();
     m_showToolTip      = cfg.value("environment/showToolTip",m_showToolTip).toBool();
+    m_showElementInfo  = cfg.value("environment/showElementInfo", m_showElementInfo).toBool();
     m_showZoomLevel    = cfg.value("environment/showZoomLevel",m_showZoomLevel).toBool();
     m_useAntiAliasing  = cfg.value("environment/useAntiAliasing",m_useAntiAliasing).toBool();
     m_reducePoiIcons   = cfg.value("environment/reducePoiIcons",m_reducePoiIcons).toBool();
@@ -258,6 +259,7 @@ CResources::~CResources()
     cfg.setValue("environment/showClock",m_showClock);
     cfg.setValue("environment/showScale",m_showScale);
     cfg.setValue("environment/showToolTip",m_showToolTip);
+    cfg.setValue("environment/showElementInfo", m_showElementInfo);
     cfg.setValue("environment/showZoomLevel",m_showZoomLevel);
     cfg.setValue("environment/useAntiAliasing",m_useAntiAliasing);
     cfg.setValue("environment/reducePoiIcons",m_reducePoiIcons);
