@@ -1,9 +1,9 @@
 /**********************************************************************************************
     Copyright (C) 2007 Oliver Eichler oliver.eichler@gmx.de
 
-    This program is free software; you can redistribute it and/or modify
+    This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
+    the Free Software Foundation, either version 3 of the License, or
     (at your option) any later version.
 
     This program is distributed in the hope that it will be useful,
@@ -12,8 +12,7 @@
     GNU General Public License for more details.
 
     You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 **********************************************************************************************/
 #ifndef CRESOURCES_H
@@ -68,6 +67,7 @@ class CResources : public QObject
         bool showClock(){return m_showClock;}
         bool showScale(){return m_showScale;}
         bool showToolTip(){return m_showToolTip;}
+        bool showElementInfo(){return m_showElementInfo;}
         bool showZoomLevel(){return m_showZoomLevel;}
         bool playSound(){return m_playSound;}
         bool useAntiAliasing(){return m_useAntiAliasing;}
@@ -163,6 +163,7 @@ class CResources : public QObject
         bool m_showClock;
         bool m_showScale;
         bool m_showToolTip;
+        bool m_showElementInfo;
         bool m_showZoomLevel;
         bool m_useAntiAliasing;
         bool m_reducePoiIcons;
