@@ -1,19 +1,18 @@
 /**********************************************************************************************
     Copyright (C) 2009 Oliver Eichler oliver.eichler@gmx.de
 
-    This program is free software; you can redistribute it and/or modify
+    This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
+    the Free Software Foundation, either version 3 of the License, or
     (at your option) any later version.
-
+    
     This program is distributed in the hope that it will be useful,
     but WITHOUT ANY WARRANTY; without even the implied warranty of
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.
-
+    
     You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 **********************************************************************************************/
 
@@ -69,11 +68,10 @@ void CRouteDB::addRoute(CRoute * route, bool silent)
     delRoute(route->getKey(), silent);
     routes[route->getKey()] = route;
 
-    connect(route,SIGNAL(sigChanged()),SIGNAL(sigChanged()));
+    connect(route,SIGNAL(sigChanged()),this, SLOT(slotModified()));
     if(!silent)
     {
         emitSigChanged();
-        emitSigModified();
     }
 
 }
@@ -87,7 +85,6 @@ void CRouteDB::delRoute(const QString& key, bool silent)
     if(!silent)
     {
         emitSigChanged();
-        emitSigModified();
     }
 }
 
@@ -102,7 +99,6 @@ void CRouteDB::delRoutes(const QStringList& keys)
     if(!keys.isEmpty())
     {
         emitSigChanged();
-        emitSigModified();
     }
 }
 
@@ -133,10 +129,13 @@ void CRouteDB::highlightRoute(const QString& key)
     {
         routes[key]->setHighlight(true);
         emit sigHighlightRoute(routes[key]);
+        emitSigModified(key);
 
     }
-
-    emitSigChanged();
+    else
+    {
+        emit sigHighlightRoute(0);
+    }
 
 }
 
@@ -440,7 +439,6 @@ void CRouteDB::download()
     }
 
     emitSigChanged();
-    emitSigModified();
 }
 
 
@@ -745,9 +743,6 @@ void CRouteDB::loadSecondaryRoute(const QString& key, QDomDocument& xml, CRoute:
     if(routes.contains(key))
     {
         routes[key]->loadSecondaryRoute(xml, service);
-        emitSigChanged();
-        emitSigModified();
-        emitSigModified(key);
     }
 }
 
@@ -757,8 +752,15 @@ void CRouteDB::reset(const QString& key)
     if(routes.contains(key))
     {
         routes[key]->reset();
-        emitSigChanged();
-        emitSigModified();
-        emitSigModified(key);
     }
 }
+
+void CRouteDB::slotModified()
+{
+    CRoute * rte = qobject_cast<CRoute*>(sender());
+    if(rte)
+    {
+        emitSigModified(rte->getKey());
+    }
+
+}
