@@ -40,6 +40,68 @@
 
 QDir CTrack::path(_MKSTR(MAPPATH) "/Track");
 
+QVector<CTrack::multi_color_setup_t> CTrack::setupMultiColor;
+
+CTrack::multi_color_setup_t::multi_color_setup_t(multi_color_setup_e modeMinMax, float min, float max, int minH, int maxH, const QString &name)
+    : modeMinMax(modeMinMax)
+    , minVal(min)
+    , markVal(WPT_NOFLOAT)
+    , maxVal(max)
+    , minHue(minH)
+    , maxHue(maxH)
+    , name(name)
+{
+    buildColorTable();
+}
+
+void CTrack::multi_color_setup_t::buildColorTable()
+{
+    if(minHue > maxHue)
+    {
+        colors.resize(minHue - maxHue + 1);
+        for(int i = 0; i<colors.size(); i++)
+        {
+            colors[i].setHsv(minHue - i, 255, 255);
+        }
+    }
+    else
+    {
+        colors.resize(maxHue - minHue + 1);
+        for(int i = 0; i<colors.size(); i++)
+        {
+            colors[i].setHsv(minHue + i, 255, 255);
+        }
+    }
+
+}
+
+void CTrack::multi_color_setup_t::save(QSettings& cfg)
+{
+    cfg.beginGroup(name);
+
+    cfg.setValue("modeMinMax", modeMinMax);
+    cfg.setValue("minVal",minVal);
+    cfg.setValue("maxVal",maxVal);
+    cfg.setValue("minHue",minHue);
+    cfg.setValue("maxHue",maxHue);
+
+    cfg.endGroup();
+}
+
+void CTrack::multi_color_setup_t::restore(QSettings& cfg)
+{
+    cfg.beginGroup(name);
+
+    modeMinMax  = (multi_color_setup_e)cfg.value("modeMinMax", modeMinMax).toInt();
+    minVal      = cfg.value("minVal",minVal).toFloat();
+    maxVal      = cfg.value("maxVal",maxVal).toFloat();
+    minHue      = cfg.value("minHue",minHue).toInt();
+    maxHue      = cfg.value("maxHue",maxHue).toInt();;
+
+    cfg.endGroup();
+}
+
+
 struct trk_head_entry_t
 {
     trk_head_entry_t() : type(CTrack::eEnd), offset(0) {}
@@ -104,6 +166,14 @@ QDataStream& operator >>(QDataStream& s, CTrack& track)
                 {
                     s1 >> track.cntMedianFilterApplied;
                 }
+                if(!s1.atEnd())
+                {
+                    s1 >> track.useMultiColor;
+                }
+                if(!s1.atEnd())
+                {
+                    s1 >> track.idMultiColor;
+                }
 
                 track.setColor(track.colorIdx);
                 track.setKey(key);
@@ -351,6 +421,8 @@ QDataStream& operator <<(QDataStream& s, CTrack& track)
     s1 << track.getParentWpt();
     s1 << track.doScaleWpt2Track;
     s1 << track.cntMedianFilterApplied;
+    s1 << track.useMultiColor;
+    s1 << track.idMultiColor;
 
     entries << entryBase;
 
@@ -689,6 +761,8 @@ CTrack::CTrack(QObject * parent)
 , cntMedianFilterApplied(0)
 , replaceOrigData(true)
 , stateSelect(e1stSel)
+, useMultiColor(false)
+, idMultiColor(eMultiColorEle)
 {
     ref = 1;
 
@@ -701,6 +775,22 @@ CTrack::CTrack(QObject * parent)
 
     connect(&CWptDB::self(), SIGNAL(sigChanged()), this, SLOT(slotScaleWpt2Track()));
     connect(&CWptDB::self(), SIGNAL(sigModified(QString)), this, SLOT(slotScaleWpt2Track()));
+
+    if(setupMultiColor.isEmpty())
+    {
+        setupMultiColor.resize(eMultiColorMax);
+        setupMultiColor[eMultiColorNone]    = multi_color_setup_t();
+        setupMultiColor[eMultiColorSlope]   = multi_color_setup_t(CTrack::eMinMaxModeNoAuto, 0, 25, 120, 0, tr("Slope [\260]"));
+        setupMultiColor[eMultiColorEle]     = multi_color_setup_t(CTrack::eMinMaxModeAuto, 0,  0, 240, 0, tr("Elevation [m]"));
+        setupMultiColor[eMultiColorSpeed]   = multi_color_setup_t(CTrack::eMinMaxModeAuto, 0,  0, 240, 0, tr("Speed [km/h]"));
+
+        SETTINGS;
+        cfg.beginGroup("MultiColorTrack");
+        setupMultiColor[eMultiColorSlope].restore(cfg);
+        setupMultiColor[eMultiColorEle].restore(cfg);
+        setupMultiColor[eMultiColorSpeed].restore(cfg);
+        cfg.endGroup();
+    }
 }
 
 
@@ -709,6 +799,151 @@ CTrack::~CTrack()
 
 }
 
+void CTrack::getMultiColor(bool& on, int& id, QList<multi_color_item_t>& items)
+{
+    items << multi_color_item_t(tr("solid"), eMultiColorNone);
+    items << multi_color_item_t(tr("slope"), eMultiColorSlope);
+    items << multi_color_item_t(tr("elevation"), eMultiColorEle);
+    items << multi_color_item_t(tr("speed"), eMultiColorSpeed);
+
+    on = useMultiColor;
+    id = idMultiColor;
+}
+
+CTrack::multi_color_setup_t& CTrack::getMultiColorSetup(int id)
+{
+    return setupMultiColor[id];
+}
+
+void CTrack::setMultiColor(bool on, int id)
+{
+     useMultiColor = on;
+     idMultiColor  = id;
+
+     rebuild(false);
+}
+
+#include "CPlotAxis.h"
+void CTrack::drawMultiColorLegend(QPainter& p)
+{
+    if(!useMultiColor)
+    {
+        return;
+    }
+
+    int     iy;
+    const multi_color_setup_t& setup = setupMultiColor[idMultiColor];
+
+    if(setup.minVal == setup.maxVal)
+    {
+        return;
+    }
+
+    CPlotAxis axis(this);
+    axis.setAutoscale(false);
+    axis.setMinMax(setup.minVal, setup.maxVal);
+    axis.setScale(200);
+
+    QFontMetrics fm(p.font());
+
+    p.save();
+    p.translate(5,0);
+
+    // draw parameter name
+    QRect recText = fm.boundingRect(setup.name);
+    recText.moveTopLeft(QPoint(0, -fm.height()*2));
+    recText.adjust(-1,-1,1,1);
+    CCanvas::drawText(setup.name,p,recText,Qt::black);
+
+    // draw color bar
+    float step = 200.0/setup.colors.size();
+    float yoff = 200;
+
+    foreach(const QColor& color, setup.colors)
+    {
+        p.setPen(color);
+        p.setBrush(color);
+        p.drawRect(QRectF(0,yoff - step, 20, step));
+        yoff -= step;
+    }
+    p.setPen(QPen(Qt::black,2));
+    p.setBrush(Qt::NoBrush);
+    p.drawRect(0,0,20,200);
+
+    // draw current value marker
+    if(setup.markVal != WPT_NOFLOAT)
+    {
+        if((setup.minVal <= setup.markVal) && (setup.markVal <= setup.maxVal))
+        {
+            iy = 200 - axis.val2pt(setup.markVal);
+            p.setPen(Qt::black);
+            p.drawLine(3,iy,17,iy);
+        }
+    }
+
+    // draw scale and tic marks
+    p.translate(20,0);
+
+    QString format_single_prec, format_double_prec;
+    QRect   recTextMin, recTextMax;
+    const CPlotAxis::TTic * t = axis.ticmark();
+    double limMin, limMax, useMin, useMax;
+
+    // min max limits first
+    axis.getLimits(limMin, limMax, useMin, useMax);
+
+    format_double_prec = axis.fmtdbl(setup.minVal);
+    if(setup.minVal >= useMin)
+    {
+        QString text = QString().sprintf( format_double_prec.toLatin1().data(), setup.minVal);
+        recText      = fm.boundingRect(text);
+        iy = 200 - axis.val2pt(setup.minVal) - fm.height() / 2;
+        recText.moveTopLeft(QPoint(10, iy));
+        recText.adjust(-1,-1,1,1);
+        CCanvas::drawText(text, p, recText,Qt::black);
+        recTextMin = recText;
+    }
+
+    format_double_prec = axis.fmtdbl(setup.maxVal);
+    if(setup.minVal >= useMin)
+    {
+        QString text = QString().sprintf( format_double_prec.toLatin1().data(), setup.maxVal);
+        recText      = fm.boundingRect(text);
+        iy = 200 - axis.val2pt(setup.maxVal) - fm.height() / 2;
+        recText.moveTopLeft(QPoint(10, iy));
+        recText.adjust(-1,-1,1,1);
+        CCanvas::drawText(text, p, recText,Qt::black);
+        recTextMax = recText;
+    }
+
+
+    // tic marks and other labels
+    while ( t )
+    {
+        iy = 200 - axis.val2pt( t->val );
+
+        p.setPen(QPen(Qt::black,2));
+        p.drawLine( 0, iy, 5, iy );
+
+        format_single_prec = axis.fmtsgl(t->val);
+        QString text = QString().sprintf( format_single_prec.toLatin1().data(), t->val );
+        recText      = fm.boundingRect(text);
+        iy = 200 - axis.val2pt(t->val ) - fm.height() / 2;
+        recText.moveTopLeft(QPoint(10, iy));
+        recText.adjust(-1,-1,1,1);
+
+        if(!recText.intersects(recTextMin) && !recText.intersects(recTextMax))
+        {
+            CCanvas::drawText(text, p, recText,Qt::black);
+        }
+
+        t = axis.ticmark( t );
+    }
+
+    p.restore();
+
+}
+
 void CTrack::setHighlight(bool yes)
 {
     highlight = yes;
@@ -953,6 +1188,8 @@ void CTrack::rebuild(bool reindex)
     QList<pt_t>::iterator pt1 = track.begin();
     QList<pt_t>::iterator pt2 = track.begin();
 
+    QList<pt_t>::iterator pt1Slope;
+
     visiblePointCount = 0;
     totalTime       = 0;
     totalTimeMoving = 0;
@@ -1007,9 +1244,12 @@ void CTrack::rebuild(bool reindex)
     pt1->descend    = totalDescend;
     pt1->dem        = dem.getElevation(pt1->lon * DEG_TO_RAD, pt1->lat * DEG_TO_RAD);
     pt1->slope      = 0.0;
+    pt1->slope2     = 0.0;
     t1              = pt1->timestamp;
     t2              = t1;        //for the case that the track has only 1 point
 
+    pt1Slope = pt1;
+
     ++visiblePointCount;
 
     if(pt1->ele   > maxEle)   {maxEle   = pt1->ele;   ptMaxEle   = *pt1;}
@@ -1111,14 +1351,220 @@ void CTrack::rebuild(bool reindex)
 
         }
 
+        if ((pt1Slope->ele != WPT_NOFLOAT) && (pt2->ele != WPT_NOFLOAT))
+        {
+            if((pt2->distance - pt1Slope->distance) > 100)
+            {
+
+            }
+        }
+
+
         pt1 = pt2;
     }
 
     totalTime = t2 - t1;
+
+    // calculate slope
+    for(int i = 0; i<track.size(); i++)
+    {
+        pt_t & pt = track[i];
+        if((pt.flags & pt_t::eDeleted) || (pt.ele == WPT_NOFLOAT))
+        {
+            pt.slope2 = WPT_NOFLOAT;
+            continue;
+        }
+
+        float d1 = pt.distance, e1 = pt.ele;
+        int n = i;
+        while(n>0)
+        {
+            pt_t & pt2 = track[n];
+            if((pt2.flags & pt_t::eDeleted) || (pt2.ele == WPT_NOFLOAT))
+            {
+                n--;
+                continue;
+            }
+
+            if(pt.distance - pt2.distance >= 25)
+            {
+                d1 = pt2.distance;
+                e1 = pt2.ele;
+                break;
+            }
+            n--;
+        }
+
+        float d2 = pt.distance, e2 = pt.ele;
+        n = i;
+        while(n < track.size())
+        {
+            pt_t & pt2 = track[n];
+            if((pt2.flags & pt_t::eDeleted) || (pt2.ele == WPT_NOFLOAT))
+            {
+                n++;
+                continue;
+            }
+
+            if(pt2.distance - pt.distance >= 25)
+            {
+                d2 = pt2.distance;
+                e2 = pt2.ele;
+                break;
+            }
+            n++;
+        }
+
+        float a  = atan((e2 - e1)/(d2 - d1));
+        pt.slope2 = fabs(a * 360.0/(2 * M_PI));
+
+    }
+
+
+    rebuildColorMap();
+
     emit sigChanged();
 }
 
 
+void CTrack::rebuildColorMap()
+{
+    if(!useMultiColor)
+    {
+        return;
+    }
+    switch(idMultiColor)
+    {
+        case eMultiColorSlope:
+            rebuildColorMapSlope();
+            break;
+        case eMultiColorEle:
+            rebuildColorMapElevation();
+            break;
+        case eMultiColorSpeed:
+            rebuildColorMapSpeed();
+            break;
+        default:
+            rebuildColorMapDefault();
+    }
+}
+
+void CTrack::rebuildColorMapElevation()
+{
+    multi_color_setup_t& setup = setupMultiColor[eMultiColorEle];
+
+    float min   = setup.minVal = setup.modeMinMax == CTrack::eMinMaxModeFixed ? setup.minVal : ptMinEle.ele;
+    float max   = setup.maxVal = setup.modeMinMax == CTrack::eMinMaxModeFixed ? setup.maxVal : ptMaxEle.ele;
+    float itvl  = float(setup.colors.size() - 1) / (max - min);
+
+    for(int i = 0; i < track.size(); i++)
+    {
+        pt_t & pt = track[i];
+        if((pt.flags & pt_t::eDeleted) || (pt.ele == WPT_NOFLOAT))
+        {
+            continue;
+        }
+
+        if(pt.ele > max)
+        {
+            pt.color = setup.colors.last();
+        }
+        else if(pt.ele < min)
+        {
+            pt.color = setup.colors.first();
+        }
+        else
+        {
+            int idx = floor((pt.ele - min) * itvl);
+            pt.color = setup.colors[idx];
+        }
+    }
+
+}
+
+void CTrack::rebuildColorMapSpeed()
+{
+    multi_color_setup_t& setup = setupMultiColor[eMultiColorSpeed];
+
+    float min   = setup.minVal = setup.modeMinMax == CTrack::eMinMaxModeFixed ? setup.minVal : ptMinSpeed.speed * 3.6;
+    float max   = setup.maxVal = setup.modeMinMax == CTrack::eMinMaxModeFixed ? setup.maxVal : ptMaxSpeed.speed * 3.6;
+
+    if(min < 0) min = setup.minVal = 0;
+
+    float itvl  = float(setup.colors.size() - 1) / (max - min);
+
+    for(int i = 0; i < track.size(); i++)
+    {
+        pt_t & pt = track[i];
+        if((pt.flags & pt_t::eDeleted) || (pt.ele == WPT_NOFLOAT))
+        {
+            continue;
+        }
+
+        if(pt.speed * 3.6 > max)
+        {
+            pt.color = setup.colors.last();
+        }
+        else if(pt.speed * 3.6 < min)
+        {
+            pt.color = setup.colors.first();
+        }
+        else
+        {
+            int idx = floor((pt.speed * 3.6 - min) * itvl);
+            pt.color = setup.colors[idx];
+        }
+    }
+
+}
+
+void CTrack::rebuildColorMapSlope()
+{
+    multi_color_setup_t& setup = setupMultiColor[eMultiColorSlope];
+
+    float min   = setup.minVal;
+    float max   = setup.maxVal;
+    float itvl  = float(setup.colors.size()- 1) / (max - min);
+
+    for(int i = 0; i < track.size(); i++)
+    {
+        pt_t & pt = track[i];
+        if((pt.flags & pt_t::eDeleted) || (pt.slope2 == WPT_NOFLOAT))
+        {
+            continue;
+        }
+
+        if(pt.slope2 > max)
+        {
+            pt.color = setup.colors.last();
+        }
+        else if(pt.slope2 < min)
+        {
+            pt.color = setup.colors.first();
+        }
+        else
+        {
+            int idx = floor((pt.slope2 - min) * itvl);
+            pt.color = setup.colors[idx];
+        }
+    }
+
+}
+
+void CTrack::rebuildColorMapDefault()
+{
+    for(int i = 0; i < track.size(); i++)
+    {
+        pt_t & pt = track[i];
+        if((pt.flags & pt_t::eDeleted) || (pt.ele == WPT_NOFLOAT))
+        {
+            continue;
+        }
+        pt.color = color;
+    }
+}
+
+
 void CTrack::setPointOfFocus(int idx, type_select_e typeSelect, bool moveMap)
 {
     // reset previous selections
@@ -1183,6 +1629,31 @@ void CTrack::setPointOfFocus(int idx, type_select_e typeSelect, bool moveMap)
                 break;
         }
     }
+    else if(typeSelect == eHoover)
+    {
+        multi_color_setup_t& setup = setupMultiColor[idMultiColor];
+        if(idx != -1)
+        {
+            switch(idMultiColor)
+            {
+                case eMultiColorSlope:
+                    setup.markVal = track[idx].slope2;
+                    break;
+                case eMultiColorEle:
+                    setup.markVal = track[idx].ele;
+                    break;
+                case eMultiColorSpeed:
+                    setup.markVal = track[idx].speed * 3.6;
+                    break;
+                default:
+                    setup.markVal = WPT_NOFLOAT;
+            }
+        }
+        else
+        {
+            setup.markVal = WPT_NOFLOAT;
+        }
+    }
     else
     {
         // erase all flags
@@ -1209,7 +1680,7 @@ void CTrack::setPointOfFocus(int idx, type_select_e typeSelect, bool moveMap)
     {
         theMainWindow->getCanvas()->move(track[idx].lon, track[idx].lat);
     }
-    emit sigChanged();
+    emit sigNeedUpdate();
 }
 
 void CTrack::getPointOfFocus(QList<CTrack::pt_t>& points)
@@ -1485,6 +1956,12 @@ QString CTrack::getTrkPtInfo1(pt_t& trkpt)
         str += tr("elevation: %1%2").arg(val).arg(unit);
     }
 
+    if(trkpt.slope2 != WPT_NOFLOAT)
+    {
+        if(str.count()) str += " ";
+        str += tr("slope: %1\260").arg(trkpt.slope2,0,'f',0);
+    }
+
     if((trkpt.heartReateBpm != -1) || (trkpt.cadenceRpm != -1))
     {
         if(str.count()) str += "\n";
