@@ -72,7 +72,7 @@ class CTrack : public IItem
         virtual ~CTrack();
         int ref;
         enum type_e {eEnd,eBase,eTrkPts,eTrain,eTrkExt1,eTrkGpxExt,eTrkShdw, eTrkShdw2, eTrkPts2};
-        enum type_select_e{eErase, eNoErase, e3Way};
+        enum type_select_e{eErase, eNoErase, e3Way, eHoover};
 
 #ifdef GPX_EXTENSIONS
         CGpxExtTr tr_ext;        //TODO: CGpxExtPt -> tr_ext
@@ -90,7 +90,7 @@ class CTrack : public IItem
 
             pt_t() : idx(-1), lon(WPT_NOFLOAT), lat(WPT_NOFLOAT), ele(WPT_NOFLOAT), timestamp(0), timestamp_msec(0),
                 speed(WPT_NOFLOAT), avgspeed(0), delta(WPT_NOFLOAT), azimuth(WPT_NOFLOAT), distance(WPT_NOFLOAT),
-                ascend(0), descend(0), heartReateBpm(-1), cadenceRpm(-1), slope(0), timeSinceStart(0),
+                ascend(0), descend(0), heartReateBpm(-1), cadenceRpm(-1), slope(0), slope2(WPT_NOFLOAT), timeSinceStart(0),
                 fix(""), sat(0), velocity(WPT_NOFLOAT), heading(WPT_NOFLOAT),
                 vdop(WPT_NOFLOAT), hdop(WPT_NOFLOAT), pdop(WPT_NOFLOAT),
                 _lon(WPT_NOFLOAT),_lat(WPT_NOFLOAT),_ele(WPT_NOFLOAT), _timestamp(0), _timestamp_msec(0),
@@ -130,6 +130,8 @@ class CTrack : public IItem
             int cadenceRpm;
             /// secondary data: slope in %
             float slope;
+            /// secondary data: slope in %
+            float slope2;
 
             quint32 timeSinceStart;
 
@@ -175,6 +177,8 @@ class CTrack : public IItem
 
             /// QTreeWidgetItem
             QPointer<QObject> editItem;
+
+            QColor color;
         };
 
         struct wpt_t
@@ -208,6 +212,8 @@ class CTrack : public IItem
         QList<pt_t>& getTrackPoints() {return track;}
         /// get polyline representation of track
         QPolygon& getPolyline() {return polyline;}
+        QVector<QColor>& getPolylineColor(){return polylineColor;}
+
         /// get the total distance of the track in [m]
         double getTotalDistance() const {return totalDistance;}
         /// get the total time covered by the track in seconds
@@ -285,6 +291,48 @@ class CTrack : public IItem
 
         void setupIterators(QList<pt_t>::iterator& begin, QList<pt_t>::iterator& end);
 
+        struct multi_color_item_t
+        {
+            multi_color_item_t(const QString& name, int id) : name(name), id(id){}
+            QString name;
+            int id;
+        };
+
+        enum multi_color_setup_e
+        {
+             eMinMaxModeNoAuto
+            ,eMinMaxModeAuto
+            ,eMinMaxModeFixed
+        };
+
+        struct multi_color_setup_t
+        {
+            multi_color_setup_t(multi_color_setup_e modeMinMax, float min, float max, int minH, int maxH, const QString& name);
+            multi_color_setup_t() : modeMinMax(eMinMaxModeNoAuto), minVal(0), markVal(WPT_NOFLOAT), maxVal(0), minHue(0), maxHue(0){}
+
+            void buildColorTable();
+            void save(QSettings& cfg);
+            void restore(QSettings& cfg);
+
+            multi_color_setup_e  modeMinMax;
+            float minVal;
+            float markVal;
+            float maxVal;
+            int   minHue;
+            int   maxHue;
+            QVector<QColor> colors;
+            QString name;
+        };
+
+        multi_color_setup_t &getMultiColorSetup(int id);
+        void getMultiColor(bool& on, int& id, QList<multi_color_item_t>& items);
+        void setMultiColor(bool on, int id);
+        bool isMultiColor(){return useMultiColor;}
+        void drawMultiColorLegend(QPainter& p);
+        void rebuildColorMap();
+
+        void emitSigNeedUpdate(){emit sigNeedUpdate();}
+
     public slots:
         void slotScaleWpt2Track();
 
@@ -293,9 +341,14 @@ class CTrack : public IItem
         void slotProxyAuthenticationRequired(const QNetworkProxy&, QAuthenticator*);
 
     private:
+        friend class CDlgMultiColorConfig;
         friend class CTrackDB;
         friend QDataStream& operator >>(QDataStream& s, CTrack& track);
-        friend QDataStream& operator <<(QDataStream& s, CTrack& track);
+        friend QDataStream& operator <<(QDataStream& s, CTrack& track);        
+        void rebuildColorMapElevation();
+        void rebuildColorMapSlope();
+        void rebuildColorMapSpeed();
+        void rebuildColorMapDefault();
 
         static QDir path;
 
@@ -327,6 +380,8 @@ class CTrack : public IItem
 
         /// the Qt polyline for faster processing
         QPolygon polyline;
+        /// the color attached to each point in polyline (only used in multicolor mode)
+        QVector<QColor> polylineColor;
 
         float avgspeed0;
         float avgspeed1;
@@ -359,6 +414,20 @@ class CTrack : public IItem
 
         QString timezone;
 
+        enum multi_color_item_e
+        {
+            eMultiColorNone
+            , eMultiColorSlope
+            , eMultiColorEle
+            , eMultiColorSpeed
+            , eMultiColorMax
+        };
+
+        quint32 useMultiColor;
+        qint32  idMultiColor;
+
+        static QVector<multi_color_setup_t> setupMultiColor;
+
 };
 
 QDataStream& operator >>(QDataStream& s, CTrack& track);
