@@ -37,7 +37,6 @@
 
 #include <QtGui>
 #include "CUndoStackModel.h"
-#include "CTrackUndoCommandDelete.h"
 #include "CTrackUndoCommandSelect.h"
 
 #if WIN32
@@ -642,6 +641,7 @@ void CTrackDB::addTrack(CTrack* track, bool silent)
     tracks[track->getKey()] = track;
 
     connect(track,SIGNAL(sigChanged()),this, SLOT(slotModified()));
+    connect(track,SIGNAL(sigNeedUpdate()),this, SLOT(slotNeedUpdate()));
     if(!silent)
     {
         emitSigChanged();
@@ -652,7 +652,10 @@ void CTrackDB::addTrack(CTrack* track, bool silent)
 void CTrackDB::delTrack(const QString& key, bool silent)
 {
     if(!tracks.contains(key)) return;
-    undoStack->push(new CTrackUndoCommandDelete(this,key,silent));
+
+    CTrack * track = take(key, silent);
+    track->deleteLater();
+
 
 }
 
@@ -667,7 +670,7 @@ void CTrackDB::delTracks(const QStringList& keys)
     undoStack->endMacro();
     if(!keys.isEmpty())
     {
-        emitSigChanged();        
+        emitSigChanged();
     }
 }
 
@@ -823,10 +826,9 @@ void CTrackDB::splitTrack(int idx)
 }
 
 
-void CTrackDB::drawLine(const QPolygon& line, const QRect& extViewport, QPainter& p)
+void CTrackDB::splitLineToViewport(const QPolygon& line, const QRect& extViewport, QList<QPolygon>& lines)
 {
     QPolygon subline;
-    QList<QPolygon> lines;
 
     int i;
     QPoint pt, ptt, pt1;
@@ -852,7 +854,7 @@ void CTrackDB::drawLine(const QPolygon& line, const QRect& extViewport, QPainter
         }
 
         ptt = pt1 - pt;
-        if(ptt.manhattanLength() < 5)
+        if(ptt.manhattanLength() < 15)
         {
             continue;
         }
@@ -866,11 +868,33 @@ void CTrackDB::drawLine(const QPolygon& line, const QRect& extViewport, QPainter
         lines << subline;
     }
 
+}
+
+void CTrackDB::drawLine(const QPolygon& line, const QRect& extViewport, QPainter& p)
+{
+    int i;
+    QList<QPolygon> lines;
+
+    splitLineToViewport(line, extViewport, lines);
+
     for(i = 0; i < lines.count(); i++)
     {
         p.drawPolyline(lines[i]);
     }
+}
 
+void CTrackDB::drawLine(const QPolygon& line, const QVector<QColor> colors, const QRect& extViewport, QPainter& p)
+{
+    QPen pen = p.pen();
+    for(int i = 1; i < line.size(); i++)
+    {
+        QLinearGradient g(line[i-1], line[i]);
+        g.setColorAt(0, colors[i-1]);
+        g.setColorAt(1, colors[i]);
+        pen.setBrush(QBrush(g));
+        p.setPen(pen);
+        p.drawLine(line[i-1], line[i]);
+    }
 }
 
 
@@ -996,8 +1020,10 @@ void CTrackDB::draw(QPainter& p, const QRect& rect, bool& needsRedraw)
             continue;
         }
 
-        QPolygon& line = (*track)->getPolyline();
+        QPolygon& line          = (*track)->getPolyline();
+        QVector<QColor>& color  = (*track)->getPolylineColor();
         line.clear();
+        color.clear();
 
         bool firstTime = (*track)->firstTime;
 
@@ -1033,7 +1059,8 @@ void CTrackDB::draw(QPainter& p, const QRect& rect, bool& needsRedraw)
                 ++trkpt; continue;
             }
 
-            line << trkpt->px;
+            line    << trkpt->px;
+            color   << trkpt->color;
             ++trkpt;
         }
 
@@ -1097,7 +1124,14 @@ void CTrackDB::draw(QPainter& p, const QRect& rect, bool& needsRedraw)
         p.setPen(pen1);
         drawLine(line, extRect, p);
         p.setPen(pen2);
-        drawLine(line, extRect, p);
+        if((*track)->isMultiColor())
+        {
+            drawLine(line, (*track)->getPolylineColor(), extRect, p);
+        }
+        else
+        {
+            drawLine(line, extRect, p);
+        }
 
         if(showBullets)
         {
@@ -1177,6 +1211,7 @@ void CTrackDB::draw(QPainter& p, const QRect& rect, bool& needsRedraw)
                 drawMarker(p, tr("Vmax=%1%2").arg(val).arg(unit), (*track)->ptMaxSpeed);
             }
         }
+
     }
 }
 
@@ -1423,6 +1458,7 @@ void CTrackDB::setPointOfFocusByDist(double distance)
         }
         ++trkpt;
     }
+    track->setPointOfFocus(idx, CTrack::eHoover, false);
     emit sigPointOfFocus(idx);
 }
 
@@ -1447,7 +1483,7 @@ void CTrackDB::setPointOfFocusByTime(quint32 timestamp)
             ++trkpt; continue;
         }
 
-        quint32 timestamp_diff = (timestamp > trkpt->timestamp)?(timestamp - trkpt->timestamp):(trkpt->timestamp - timestamp);
+        qint32 timestamp_diff = (timestamp > trkpt->timestamp)?(timestamp - trkpt->timestamp):(trkpt->timestamp - timestamp);
         if(timestamp_diff < d)
         {
             d   = timestamp_diff;
@@ -1455,6 +1491,7 @@ void CTrackDB::setPointOfFocusByTime(quint32 timestamp)
         }
         ++trkpt;
     }
+    track->setPointOfFocus(idx, CTrack::eHoover, false);
     emit sigPointOfFocus(idx);
 }
 
@@ -1470,10 +1507,12 @@ void CTrackDB::setPointOfFocusByIdx(qint32 idx)
     QList<CTrack::pt_t>& trkpts = track->getTrackPoints();
     if(idx < trkpts.size())
     {
+        track->setPointOfFocus(idx, CTrack::eHoover, false);
         emit sigPointOfFocus(idx);
     }
     else
     {
+        track->setPointOfFocus(-1, CTrack::eHoover, false);
         emit sigPointOfFocus(-1);
     }
 }
@@ -1560,7 +1599,9 @@ void CTrackDB::slotMapChanged()
 {
     foreach(CTrack * track, tracks)
     {
+        track->blockSignals(true);
         track->rebuild(false);
+        track->blockSignals(false);
     }
 }
 
@@ -1573,3 +1614,12 @@ void CTrackDB::slotModified()
     }
 }
 
+void CTrackDB::slotNeedUpdate()
+{
+    CTrack * trk = qobject_cast<CTrack*>(sender());
+    if(trk)
+    {
+        emitSigNeedUpdate(trk->getKey());
+    }
+}
+
