@@ -5,12 +5,12 @@
     it under the terms of the GNU General Public License as published by
     the Free Software Foundation, either version 3 of the License, or
     (at your option) any later version.
-    
+
     This program is distributed in the hope that it will be useful,
     but WITHOUT ANY WARRANTY; without even the implied warranty of
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.
-    
+
     You should have received a copy of the GNU General Public License
     along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
@@ -37,6 +37,7 @@
 #include "CWptDB.h"
 #include "CSettings.h"
 #include "CPlot.h"
+#include "CDlgMultiColorConfig.h"
 
 #include <QtGui>
 
@@ -182,6 +183,9 @@ CTrackEditWidget::CTrackEditWidget(QWidget * parent)
     connect(tabWidget, SIGNAL(currentChanged(int)), this, SLOT(slotCurrentChanged(int)));
     connect(checkStages, SIGNAL(stateChanged(int)), this, SLOT(slotStagesChanged(int)));
     connect(textStages, SIGNAL(sigHighlightArea(QString)), this, SLOT(slotHighlightArea(QString)));
+    connect(checkMultiColor, SIGNAL(toggled(bool)), this, SLOT(slotToggleMultiColor(bool)));
+    connect(comboMultiColor, SIGNAL(currentIndexChanged(int)), this, SLOT(slotMultiColorMode(int)));
+    connect(toolMuliColorConfig, SIGNAL(clicked()), this, SLOT(slotMultiColorConfig()));
 
     connect(&CTrackDB::self(), SIGNAL(sigModified(const QString&)), this, SLOT(slotStagesChanged()));
     connect(&CTrackDB::self(), SIGNAL(sigPointOfFocus(int)), this, SLOT(slotPointOfFocus(int)));
@@ -335,8 +339,9 @@ void CTrackEditWidget::slotSetTrack(CTrack * t)
 
     if(track)
     {
-        disconnect(track,SIGNAL(sigChanged()), this, SLOT(slotUpdate()));
-        disconnect(track,SIGNAL(destroyed(QObject*)), this, SLOT(deleteLater()));
+        disconnect(track, SIGNAL(sigChanged()), this, SLOT(slotUpdate()));
+        disconnect(track, SIGNAL(sigNeedUpdate()), this, SLOT(slotUpdate()));
+        disconnect(track, SIGNAL(destroyed(QObject*)), this, SLOT(deleteLater()));
 
 #ifdef GPX_EXTENSIONS
         //delete all extension tabs and reset tab status
@@ -469,6 +474,21 @@ void CTrackEditWidget::slotSetTrack(CTrack * t)
 
     QApplication::setOverrideCursor(Qt::WaitCursor);
 
+    bool on;
+    int id;
+    QList<CTrack::multi_color_item_t> multiColorItems;
+    track->getMultiColor(on, id, multiColorItems);
+
+    track->blockSignals(true);
+    comboMultiColor->clear();
+    foreach(const CTrack::multi_color_item_t& item, multiColorItems)
+    {
+        comboMultiColor->addItem(item.name,item.id);
+    }
+    comboMultiColor->setCurrentIndex(id);
+    checkMultiColor->setChecked(on);
+    track->blockSignals(false);
+
     QList<CTrack::pt_t>& trkpts           = track->getTrackPoints();
     QList<CTrack::pt_t>::iterator trkpt   = trkpts.begin();
     while(trkpt != trkpts.end())
@@ -478,6 +498,7 @@ void CTrackEditWidget::slotSetTrack(CTrack * t)
     }
 
     connect(track,SIGNAL(sigChanged()), this, SLOT(slotUpdate()));
+    connect(track, SIGNAL(sigNeedUpdate()), this, SLOT(slotUpdate()));
     connect(track,SIGNAL(destroyed(QObject*)), this, SLOT(deleteLater()));
 
     slotUpdate();
@@ -658,7 +679,7 @@ void CTrackEditWidget::slotUpdate()
 
         // timestamp
         if(trkpt->timestamp != 0x00000000 && trkpt->timestamp != 0xFFFFFFFF)
-        {            
+        {
             QDateTime time = QDateTime::fromTime_t(trkpt->timestamp);
             if(!timezone.isEmpty())
             {
@@ -793,6 +814,7 @@ void CTrackEditWidget::slotPointSelectionChanged()
     QList<CTrack::pt_t>::iterator trkpt   = trkpts.begin();
     while(trkpt != trkpts.end())
     {
+        trkpt->flags &= ~CTrack::pt_t::eFocus;
         trkpt->flags &= ~CTrack::pt_t::eSelected;
         ++trkpt;
     }
@@ -803,11 +825,19 @@ void CTrackEditWidget::slotPointSelectionChanged()
     while(item != items.end())
     {
         quint32 idxTrkPt = (*item)->data(0,Qt::UserRole).toUInt();
+        //trkpts[idxTrkPt].flags |= CTrack::pt_t::eFocus;
         trkpts[idxTrkPt].flags |= CTrack::pt_t::eSelected;
         ++item;
     }
+    if(!items.isEmpty())
+    {
+        quint32 idxTrkPt = items.last()->data(0,Qt::UserRole).toUInt();
+        trkpts[idxTrkPt].flags |= CTrack::pt_t::eFocus;
+    }
+
     originator = true;
-    track->rebuild(false);
+    //track->rebuild(false);
+    track->emitSigNeedUpdate();
     originator = false;
 }
 
@@ -1381,6 +1411,41 @@ void CTrackEditWidget::slotHighlightArea(const QString& key)
     }
 }
 
+void CTrackEditWidget::slotToggleMultiColor(bool on)
+{
+    comboColor->setEnabled(!on);
+    comboMultiColor->setEnabled(on);
+    toolMuliColorConfig->setEnabled(on);
+
+    if(track.isNull()) return;
+    track->setMultiColor(on, comboMultiColor->currentIndex());
+}
+
+void CTrackEditWidget::slotMultiColorMode(int idx)
+{
+    if(track.isNull()) return;
+    track->setMultiColor(checkMultiColor->isChecked(), idx);
+}
+
+void CTrackEditWidget::slotMultiColorConfig()
+{
+    if(track.isNull()) return;
+
+    CTrack::multi_color_setup_t& setup = track->getMultiColorSetup(comboMultiColor->currentIndex());
+    CDlgMultiColorConfig dlg(setup);
+    if(dlg.exec() == QDialog::QDialog::Rejected)
+    {
+        return;
+    }
+
+    track->rebuildColorMap();
+
+    SETTINGS;
+    cfg.beginGroup("MultiColorTrack");
+    setup.save(cfg);
+    cfg.endGroup();
+
+}
 
 #define CHAR_PER_LINE 120
 #define ROOT_FRAME_MARGIN 5
