@@ -1,18 +1,19 @@
-//C-  -*- C++ -*-
-//C- -------------------------------------------------------------------
-//C- Copyright (c) 2009 Marc Feld
-//C-
-//C- This software is subject to, and may be distributed under, the
-//C- GNU General Public License, either version 2 of the license,
-//C- or (at your option) any later version. The license should have
-//C- accompanied the software or you may obtain a copy of the license
-//C- from the Free Software Foundation at http://www.fsf.org .
-//C-
-//C- This program is distributed in the hope that it will be useful,
-//C- but WITHOUT ANY WARRANTY; without even the implied warranty of
-//C- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-//C- GNU General Public License for more details.
-//C-  ------------------------------------------------------------------
+/** ********************************************************************************************
+    Copyright (c) 2009 Marc Feld
+
+This program is free software: you can redistribute it and/or modify
+it under the terms of the GNU General Public License as published by
+the Free Software Foundation, either version 3 of the License, or
+(at your option) any later version.
+
+This program is distributed in the hope that it will be useful,
+but WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+GNU General Public License for more details.
+
+You should have received a copy of the GNU General Public License
+along with this program.  If not, see <http://www.gnu.org/licenses/>.
+********************************************************************************************* */
 
 #include "CTrackUndoCommandPurgePts.h"
 #include <QObject>
@@ -57,7 +58,6 @@ void CTrackUndoCommandPurgePts::redo()
         ++trkpt;
     }
     track->rebuild(false);
-    emit CTrackDB::self().emitSigModified();
     emit CTrackDB::self().emitSigChanged();
 }
 
@@ -85,6 +85,5 @@ void CTrackUndoCommandPurgePts::undo()
         ++trkpt;
     }
     track->rebuild(false);
-    emit CTrackDB::self().emitSigModified();
     emit CTrackDB::self().emitSigChanged();
 }
