@@ -2,9 +2,9 @@
     Copyright (C) 2007 Oliver Eichler oliver.eichler@gmx.de
     Copyright (C) 2010 Joerg Wunsch <j@uriah.heep.sax.de>
 
-    This program is free software; you can redistribute it and/or modify
+    This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
+    the Free Software Foundation, either version 3 of the License, or
     (at your option) any later version.
 
     This program is distributed in the hope that it will be useful,
@@ -13,8 +13,7 @@
     GNU General Public License for more details.
 
     You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 **********************************************************************************************/
 
@@ -314,7 +313,6 @@ CWpt * CWptDB::newWpt(float lon, float lat, float ele, const QString& name)
     cfg.setValue("waypoint/lastSymbol",wpt->iconString);
 
     emitSigChanged();
-    emitSigModified();
 
     lastWptName = wpt->getName();
 
@@ -351,7 +349,6 @@ void CWptDB::delWpt(const QString& key, bool silent, bool saveSticky)
     if(!silent)
     {
         emitSigChanged();
-        emitSigModified();
     }
 }
 
@@ -367,7 +364,6 @@ void CWptDB::delWpt(const QStringList& keys, bool saveSticky)
     if(!keys.isEmpty())
     {
         emitSigChanged();
-        emitSigModified();
     }
 }
 
@@ -388,10 +384,10 @@ void CWptDB::addWpt(CWpt * wpt, bool silent)
     }
     wpts[wpt->getKey()] = wpt;
 
+    connect(wpt,SIGNAL(sigChanged()),this, SLOT(slotModified()));
     if(!silent)
     {
         emitSigChanged();
-        emitSigModified();
     }
 }
 
@@ -405,7 +401,6 @@ void CWptDB::setProxyDistance(const QStringList& keys, double dist)
         emitSigModified(key);
     }
     emitSigChanged();
-    emitSigModified();
 
 }
 
@@ -425,7 +420,6 @@ void CWptDB::setIcon(const QStringList& keys, const QString& iconName)
         }
     }
     emitSigChanged();
-    emitSigModified();
 
 }
 
@@ -445,7 +439,6 @@ void CWptDB::setParentWpt(const QStringList& keys, const QString& name)
         }
     }
     emitSigChanged();
-    emitSigModified();
 
 }
 
@@ -889,7 +882,6 @@ void CWptDB::download()
     }
 
     emitSigChanged();
-    emitSigModified();
 }
 
 
@@ -1246,6 +1238,20 @@ static void exifContentForeachEntryFuncGPS(ExifEntry * exifEntry, void *user_dat
 }
 
 
+static const char * lookOrientTbl[] =
+{
+    ""
+    ,"top, left side"
+    ,"top, right side"
+    ,"bottom, right side"
+    ,"bottom, left side"
+    ,"left side, top"
+    ,"right side, top"
+    ,"right side, bottom"
+    ,"left side, bottom"
+
+};
+
 static void exifContentForeachEntryFunc0(ExifEntry * exifEntry, void *user_data)
 {
     CWptDB::exifGPS_t& exifGPS = *(CWptDB::exifGPS_t*)user_data;
@@ -1261,6 +1267,13 @@ static void exifContentForeachEntryFunc0(ExifEntry * exifEntry, void *user_data)
             exifGPS.timestamp   = timestamp.toTime_t();
             break;
         }
+        case EXIF_TAG_ORIENTATION:
+        {
+            exifGPS.orient = exifEntry->data[0];
+            qDebug() << "Orientation" << lookOrientTbl[exifGPS.orient];
+            break;
+        }
+
         default:;
     }
 
@@ -1333,7 +1346,6 @@ void CWptDB::createWaypointsFromImages(const QStringList& files, exifMode_e mode
         f_exif_data_unref(exifData);
     }
     emitSigChanged();
-    emitSigModified();
 }
 
 
@@ -1400,7 +1412,6 @@ void CWptDB::createWaypointsFromImages(const QStringList& files, exifMode_e mode
     }
 
     emitSigChanged();
-    emitSigModified();
 }
 
 
@@ -1417,7 +1428,37 @@ void CWptDB::addWptFromExif(const exifGPS_t& exif, exifMode_e mode, const QStrin
 
     CWpt::image_t image;
 
-    QPixmap pixtmp(filename.toLocal8Bit());
+    QImage pixtmp(filename);
+
+    QTransform transform;
+    switch(exif.orient)
+    {
+        case 1:
+            break;
+        case 2:
+            pixtmp = pixtmp.mirrored(true,false);
+            break;
+        case 3:
+            pixtmp = pixtmp.transformed(transform.rotate(180));
+            break;
+        case 4:
+            pixtmp = pixtmp.mirrored(false,true);
+            break;
+        case 5:
+            pixtmp = pixtmp.transformed(transform.transposed());
+            break;
+        case 6:
+            pixtmp = pixtmp.transformed(transform.rotate(90));
+            break;
+        case 7:
+            pixtmp = pixtmp.transformed(transform.rotate(270)).mirrored(true,false);
+            break;
+        case 8:
+            pixtmp = pixtmp.transformed(transform.rotate(270));
+            break;
+    }
+
+
     int w = pixtmp.width();
     int h = pixtmp.height();
 
@@ -1433,7 +1474,7 @@ void CWptDB::addWptFromExif(const exifGPS_t& exif, exifMode_e mode, const QStrin
             h *= 600.0 / w;
             w  = 600;
         }
-        image.pixmap = pixtmp.scaled(w,h,Qt::KeepAspectRatio, Qt::SmoothTransformation);
+        image.pixmap = QPixmap::fromImage(pixtmp.scaled(w,h,Qt::KeepAspectRatio, Qt::SmoothTransformation));
     }
     else if(mode == eExifModeLarge)
     {
@@ -1447,11 +1488,11 @@ void CWptDB::addWptFromExif(const exifGPS_t& exif, exifMode_e mode, const QStrin
             h *= 1024.0 / w;
             w  = 1024;
         }
-        image.pixmap = pixtmp.scaled(w,h,Qt::KeepAspectRatio, Qt::SmoothTransformation);
+        image.pixmap = QPixmap::fromImage(pixtmp.scaled(w,h,Qt::KeepAspectRatio, Qt::SmoothTransformation));
     }
     else if(mode == eExifModeOriginal)
     {
-        image.pixmap = pixtmp;
+        image.pixmap = QPixmap::fromImage(pixtmp);
     }
     else if(mode == eExifModeLink)
     {
@@ -1515,3 +1556,13 @@ void CWptDB::getListOfGeoCaches(QStringList& caches)
     }
 
 }
+
+void CWptDB::slotModified()
+{
+    CWpt * wpt = qobject_cast<CWpt*>(sender());
+    if(wpt)
+    {
+        emitSigModified(wpt->getKey());
+    }
+}
+
