@@ -1,9 +1,9 @@
 /**********************************************************************************************
     Copyright (C) 2007 Oliver Eichler oliver.eichler@gmx.de
 
-    This program is free software; you can redistribute it and/or modify
+    This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
+    the Free Software Foundation, either version 3 of the License, or
     (at your option) any later version.
 
     This program is distributed in the hope that it will be useful,
@@ -12,8 +12,7 @@
     GNU General Public License for more details.
 
     You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 **********************************************************************************************/
 #ifndef CWPTDB_H
@@ -113,11 +112,12 @@ class CWptDB : public IDB
 
         struct exifGPS_t
         {
-            exifGPS_t(ExifByteOrder exif_byte_order): lon(0.0), lat(0.0), ele(1e25f), lon_sign(1), lat_sign(1), byte_order(exif_byte_order) {}
+            exifGPS_t(ExifByteOrder exif_byte_order): lon(0.0), lat(0.0), ele(1e25f), dir(1e25f), orient(1), lon_sign(1), lat_sign(1), byte_order(exif_byte_order) {}
             double lon;
             double lat;
             double ele;
             double dir;
+            int    orient;
 
             int lon_sign;
             int lat_sign;
@@ -147,6 +147,9 @@ class CWptDB : public IDB
 
         bool contains(const QString& key){return wpts.contains(key);}
 
+    private slots:
+        void slotModified();
+
     private:
         friend class CMainWindow;
         friend class CDlgEditWpt;
