@@ -92,6 +92,9 @@ class IMouse : public QObject
         CGpxExtTr tr_ext;        //TODO: CGpxExtPt -> tr_ext
 #endif
 
+    public slots:
+        void slotMapChanged();
+
     protected slots:
         void slotSetPos1();
 
@@ -161,6 +164,8 @@ class IMouse : public QObject
 
         void sortSelWpts(QList<wpt_t>& list);
 
+        void clearSelWpts();
+
         /// trigger waypoint function
         void mousePressEventWpt(QMouseEvent * e);
         /// trigger search function
